/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id$
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQBANKING_VERSION_H
#define AQBANKING_VERSION_H

#define AQBANKING_VERSION_MAJOR 3
#define AQBANKING_VERSION_MINOR 8
#define AQBANKING_VERSION_PATCHLEVEL 1
#define AQBANKING_VERSION_BUILD 0
#define AQBANKING_VERSION_TAG "stable"
#define AQBANKING_VERSION_FULL_STRING "3.8.1.0stable"
#define AQBANKING_VERSION_STRING "3.8.1"


#define AQBANKING_SO_CURRENT 28
#define AQBANKING_SO_REVISION 1
#define AQBANKING_SO_AGE 8
#define AQBANKING_SO_EFFECTIVE 20

#endif /* AQBANKING_VERSION_H */


